def print_lol(the_list):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            p(each_item)
            
def p(content):
    print(content)
            



from distutils.core import setup

setup(
        name = "chenlayz",
        version = "1.0.0",
        py_modules = ['nester'],
        author = 'chenanze',
        author_email = 'chenanze@live.com',
        url = 'http://www.chenanze.com',
        description = 'A simple printer of neted lists',
    )
